import { FunctionManager } from "../managers/FunctionManager";
import { Data, DatabaseManager } from "../main";
import { TypedEmitter } from "tiny-typed-emitter";
import { Addon } from "./Addon";
import * as F from "fastify";
export interface EATS_Events {
    error: (exception: Error) => any;
    request: (data: Data) => any;
    ready: (data: Data) => any;
}
export interface EATS_API_OPTIONS extends F.FastifyServerOptions {
    addons?: Addon[];
    dots?: boolean;
    reverse?: boolean;
    debug?: boolean;
}
/**
 * Represents an easy-api.ts route.
 */
export interface EATS_ROUTE {
    method: F.HTTPMethods;
    url: string;
    code: string;
    comments?: boolean;
    reverse?: boolean;
    /**
     * Additional information about this route.
     */
    extraData?: Record<string, any>;
}
export interface EATS_EVENT {
    name: keyof EATS_Events;
    code: string;
    comments?: boolean;
    reverse?: boolean;
}
/**
 * The main hub of your API.
 */
export declare class API extends TypedEmitter<EATS_Events> {
    #private;
    options: EATS_API_OPTIONS;
    app: F.FastifyInstance;
    functions: FunctionManager;
    private interpreter;
    db: DatabaseManager<import("midb").Database>;
    constructor(options: EATS_API_OPTIONS);
    /**
     * Adds a route to the API.
     * @param data - Object structure of the route.
     * @returns {void}
     */
    route(data: EATS_ROUTE): void;
    /**
     * Run code when events gets emitted.
     * @param data - Object structure of the event.
     * @returns {void}
     */
    event(data: EATS_EVENT): void;
    /**
     * Loads routes and events using this method.
     * @param dir - Files directory to be loaded.
     * @returns {void}
     */
    load(dir: string): void;
    /**
     * Set the not found (404) error handler.
     * @param code - Code to be executed when error handler is triggered.
     * @returns {void}
     */
    setNotFoundHandler(code: string): void;
    /**
     * Connects the API.
     * @param options - Connection options.
     * @returns {void}
     */
    connect(options: F.FastifyListenOptions): void;
    /**
     * Whether "rs" syntax is enabled.
     */
    get rs(): boolean;
}
